@@ -5,9 +5,9 @@ pub mod fixedtimestep;
 pub mod state;
 
 pub mod prelude {
-    pub use crate::condition::IntoConditionalSystem;
+    pub use crate::condition::{IntoConditionalSystem, ConditionSet, AddConditionalToSet};
     #[cfg(feature = "fixedtimestep")]
-    pub use crate::fixedtimestep::FixedTimestepStage;
+    pub use crate::fixedtimestep::{FixedTimestepInfo, FixedTimestepStage};
     #[cfg(feature = "states")]
     pub use crate::state::{CurrentState, NextState, StateTransitionStage};
 }
